@@ -1099,7 +1099,7 @@ folder_bar_message (EAddressbookView *view,
 	if (view->priv->source == NULL)
 		return;
 
-	display_name = e_source_peek_name (view->priv->source);
+	display_name = e_source_get_display_name (view->priv->source);
 	e_shell_sidebar_set_primary_text (shell_sidebar, display_name);
 	e_shell_sidebar_set_secondary_text (shell_sidebar, message);
 }
