@@ -106,7 +106,8 @@ eab_contact_list_from_string (const gchar *str)
 
 			q += 9;
 			temp = q;
-			temp += strspn (temp, "\r\n\t ");
+			if (*temp)
+				temp += strspn (temp, "\r\n\t ");
 
 			if (*temp == '\0' || !g_ascii_strncasecmp (temp, "BEGIN:VCARD", 11))
 				break;  /* Found the outer END:VCARD */
@@ -135,6 +136,7 @@ eab_contact_list_to_string (const GSList *contacts)
 		EContact *contact = l->data;
 		gchar *vcard_str;
 
+		e_contact_inline_local_photos (contact, NULL);
 		vcard_str = e_vcard_to_string (
 			E_VCARD (contact), EVC_FORMAT_VCARD_30);
 
@@ -180,7 +182,7 @@ eab_book_and_contact_list_from_string (const gchar *str,
 	*book_client = e_book_client_new_from_uri (uri, NULL);
 	g_free (uri);
 
-	return *book_client ? TRUE : FALSE;
+	return (*book_client != NULL);
 }
 
 gchar *
@@ -193,11 +195,11 @@ eab_book_and_contact_list_to_string (EBookClient *book_client,
 	if (!s0)
 		s0 = g_strdup ("");
 
-	if (book_client)
+	if (book_client != NULL) {
 		s1 = g_strconcat (
 			"Book: ", e_client_get_uri (
 			E_CLIENT (book_client)), "\r\n", s0, NULL);
-	else
+	} else
 		s1 = g_strdup (s0);
 
 	g_free (s0);
