@@ -1022,7 +1022,7 @@ edit_component (ECalClient *cal_client,
 	 *     How are other apps expected to know this stuff? */
 
 	source = e_client_get_source (E_CLIENT (cal_client));
-	source_uid = e_source_peek_uid (source);
+	source_uid = e_source_get_uid (source);
 
 	e_cal_component_get_uid (comp, &comp_uid);
 
@@ -1465,7 +1465,6 @@ open_alarm_dialog (TrayIconData *tray_data)
 			gtk_tree_selection_select_iter (
 				selection, &tray_data->iter);
 
-			gtk_window_present (GTK_WINDOW (alarm_notifications_dialog->dialog));
 		}
 
 	} else {
