@@ -37,6 +37,10 @@
 #include "e-cell-date-edit-text.h"
 #include "misc.h"
 
+#define E_CAL_MODEL_TASKS_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), E_TYPE_CAL_MODEL_TASKS, ECalModelTasksPrivate))
+
 struct _ECalModelTasksPrivate {
 	gboolean highlight_due_today;
 	gchar *color_due_today;
@@ -148,7 +152,7 @@ cal_model_tasks_finalize (GObject *object)
 {
 	ECalModelTasksPrivate *priv;
 
-	priv = E_CAL_MODEL_TASKS (object)->priv;
+	priv = E_CAL_MODEL_TASKS_GET_PRIVATE (object);
 
 	g_free (priv->color_due_today);
 	g_free (priv->color_overdue);
@@ -230,8 +234,7 @@ e_cal_model_tasks_class_init (ECalModelTasksClass *class)
 static void
 e_cal_model_tasks_init (ECalModelTasks *model)
 {
-	model->priv = G_TYPE_INSTANCE_GET_PRIVATE (
-		model, E_TYPE_CAL_MODEL_TASKS, ECalModelTasksPrivate);
+	model->priv = E_CAL_MODEL_TASKS_GET_PRIVATE (model);
 
 	model->priv->highlight_due_today = TRUE;
 	model->priv->highlight_overdue = TRUE;
