@@ -60,6 +60,10 @@
 #include <e-util/e-icon-factory.h>
 #include "misc.h"
 
+#define E_MEMO_TABLE_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), E_TYPE_MEMO_TABLE, EMemoTablePrivate))
+
 struct _EMemoTablePrivate {
 	gpointer shell_view;  /* weak pointer */
 	ECalModel *model;
@@ -92,6 +96,18 @@ static const gchar *icon_names[] = {
 	"stock_insert-note"
 };
 
+/* Forward Declarations */
+static void	e_memo_table_selectable_init
+					(ESelectableInterface *interface);
+
+G_DEFINE_TYPE_WITH_CODE (
+	EMemoTable,
+	e_memo_table,
+	E_TYPE_TABLE,
+	G_IMPLEMENT_INTERFACE (
+		E_TYPE_SELECTABLE,
+		e_memo_table_selectable_init))
+
 static void
 memo_table_emit_open_component (EMemoTable *memo_table,
                                 ECalModelComponent *comp_data)
@@ -121,8 +137,8 @@ memo_table_emit_status_message (EMemoTable *memo_table,
 }
 
 /* Returns the current time, for the ECellDateEdit items.
-   FIXME: Should probably use the timezone of the item rather than the
-   current timezone, though that may be difficult to get from here. */
+ * FIXME: Should probably use the timezone of the item rather than the
+ * current timezone, though that may be difficult to get from here. */
 static struct tm
 memo_table_get_current_time (ECellDateEdit *ecde,
                              gpointer user_data)
@@ -163,9 +179,9 @@ memo_table_model_cal_view_progress_cb (EMemoTable *memo_table,
 }
 
 static void
-memo_table_model_cal_view_complete_cb ( EMemoTable *memo_table,
-					const GError *error,
-					ECalClientSourceType type)
+memo_table_model_cal_view_complete_cb (EMemoTable *memo_table,
+                                       const GError *error,
+                                       ECalClientSourceType type)
 {
 	memo_table_emit_status_message (memo_table, NULL, -1.0);
 }
@@ -186,8 +202,10 @@ delete_selected_components (EMemoTable *memo_table)
 		ECalModelComponent *comp_data = (ECalModelComponent *) l->data;
 		GError *error = NULL;
 
-		e_cal_client_remove_object_sync (comp_data->client,
-				     icalcomponent_get_uid (comp_data->icalcomp), NULL, CALOBJ_MOD_THIS, NULL, &error);
+		e_cal_client_remove_object_sync (
+			comp_data->client,
+			icalcomponent_get_uid (comp_data->icalcomp),
+			NULL, CALOBJ_MOD_THIS, NULL, &error);
 		delete_error_dialog (error, E_CAL_COMPONENT_JOURNAL);
 		g_clear_error (&error);
 	}
@@ -292,7 +310,7 @@ memo_table_dispose (GObject *object)
 {
 	EMemoTablePrivate *priv;
 
-	priv = E_MEMO_TABLE (object)->priv;
+	priv = E_MEMO_TABLE_GET_PRIVATE (object);
 
 	if (priv->shell_view != NULL) {
 		g_object_remove_weak_pointer (
@@ -547,6 +565,8 @@ memo_table_query_tooltip (GtkWidget *widget,
 		gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (w), l, FALSE, FALSE, 0);
 		g_free (tmp);
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	e_cal_component_get_dtstart (new_comp, &dtstart);
@@ -609,6 +629,8 @@ memo_table_query_tooltip (GtkWidget *widget,
 		l = gtk_label_new (tmp2->str);
 		gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
 		gtk_box_pack_start (GTK_BOX (w), l, FALSE, FALSE, 0);
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	g_string_free (tmp2, TRUE);
@@ -636,7 +658,9 @@ memo_table_query_tooltip (GtkWidget *widget,
 	if (tmp2->len) {
 		l = gtk_label_new (tmp2->str);
 		gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
-		gtk_box_pack_start (GTK_BOX (box), l, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (w), l, FALSE, FALSE, 0);
+
+		gtk_widget_modify_fg (l, GTK_STATE_NORMAL, &(style->text[GTK_STATE_NORMAL]));
 	}
 
 	g_string_free (tmp2, TRUE);
@@ -703,7 +727,8 @@ memo_table_update_actions (ESelectable *selectable,
 	for (iter = list; iter != NULL && sources_are_editable; iter = iter->next) {
 		ECalModelComponent *comp_data = iter->data;
 
-		sources_are_editable = sources_are_editable && !e_client_is_readonly (E_CLIENT (comp_data->client));
+		sources_are_editable = sources_are_editable &&
+			!e_client_is_readonly (E_CLIENT (comp_data->client));
 	}
 	g_slist_free (list);
 
@@ -756,7 +781,8 @@ memo_table_cut_clipboard (ESelectable *selectable)
 
 /* Helper for memo_table_copy_clipboard() */
 static void
-copy_row_cb (gint model_row, gpointer data)
+copy_row_cb (gint model_row,
+             gpointer data)
 {
 	EMemoTable *memo_table;
 	ECalModelComponent *comp_data;
@@ -885,8 +911,10 @@ clipboard_get_calendar_data (EMemoTable *memo_table,
 				g_free (uid);
 				g_object_unref (tmp_comp);
 
-				if (error) {
-					g_debug ("%s: Failed to create object: %s", G_STRFUNC, error->message);
+				if (error != NULL) {
+					g_warning (
+						"%s: Failed to create object: %s",
+						G_STRFUNC, error->message);
 					g_error_free (error);
 				}
 			}
@@ -909,8 +937,10 @@ clipboard_get_calendar_data (EMemoTable *memo_table,
 		g_free (uid);
 		g_object_unref (comp);
 
-		if (error) {
-			g_debug ("%s: Failed to create object: %s", G_STRFUNC, error->message);
+		if (error != NULL) {
+			g_warning (
+				"%s: Failed to create object: %s",
+				G_STRFUNC, error->message);
 			g_error_free (error);
 		}
 	}
@@ -963,7 +993,8 @@ memo_table_paste_clipboard (ESelectable *selectable)
  * gint pointed to by the closure data.
  */
 static void
-get_selected_row_cb (gint model_row, gpointer data)
+get_selected_row_cb (gint model_row,
+                     gpointer data)
 {
 	gint *row;
 
@@ -1044,7 +1075,7 @@ memo_table_select_all (ESelectable *selectable)
 }
 
 static void
-memo_table_class_init (EMemoTableClass *class)
+e_memo_table_class_init (EMemoTableClass *class)
 {
 	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
@@ -1133,12 +1164,11 @@ memo_table_class_init (EMemoTableClass *class)
 }
 
 static void
-memo_table_init (EMemoTable *memo_table)
+e_memo_table_init (EMemoTable *memo_table)
 {
 	GtkTargetList *target_list;
 
-	memo_table->priv = G_TYPE_INSTANCE_GET_PRIVATE (
-		memo_table, E_TYPE_MEMO_TABLE, EMemoTablePrivate);
+	memo_table->priv = E_MEMO_TABLE_GET_PRIVATE (memo_table);
 
 	target_list = gtk_target_list_new (NULL, 0);
 	e_target_list_add_calendar_targets (target_list, 0);
@@ -1150,7 +1180,7 @@ memo_table_init (EMemoTable *memo_table)
 }
 
 static void
-memo_table_selectable_init (ESelectableInterface *interface)
+e_memo_table_selectable_init (ESelectableInterface *interface)
 {
 	interface->update_actions = memo_table_update_actions;
 	interface->cut_clipboard = memo_table_cut_clipboard;
@@ -1160,41 +1190,6 @@ memo_table_selectable_init (ESelectableInterface *interface)
 	interface->select_all = memo_table_select_all;
 }
 
-GType
-e_memo_table_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) {
-		static const GTypeInfo type_info = {
-			sizeof (EMemoTableClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) memo_table_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,  /* class_data */
-			sizeof (EMemoTable),
-			0,     /* n_preallocs */
-			(GInstanceInitFunc) memo_table_init,
-			NULL   /* value_table */
-		};
-
-		static const GInterfaceInfo selectable_info = {
-			(GInterfaceInitFunc) memo_table_selectable_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL   /* interface_data */
-		};
-
-		type = g_type_register_static (
-			E_TYPE_TABLE, "EMemoTable", &type_info, 0);
-
-		g_type_add_interface_static (
-			type, E_TYPE_SELECTABLE, &selectable_info);
-	}
-
-	return type;
-}
-
 /**
  * e_memo_table_new:
  * @shell_view: an #EShellView
@@ -1248,7 +1243,8 @@ struct get_selected_uids_closure {
 
 /* Used from e_table_selected_row_foreach(), builds a list of the selected UIDs */
 static void
-add_uid_cb (gint model_row, gpointer data)
+add_uid_cb (gint model_row,
+            gpointer data)
 {
 	struct get_selected_uids_closure *closure;
 	ECalModelComponent *comp_data;
