@@ -1692,8 +1692,8 @@ hide_completed_rows_ready (GObject *source_object,
 
 			g_debug ("%s: Could not get the objects from '%s': %s",
 				G_STRFUNC,
-				source ? e_source_get_display_name (source) : "???",
-				error ? error->message : "Uknown error");
+				e_source_get_display_name (source),
+				error ? error->message : "Unknown error");
 		}
 		g_clear_error (&error);
 		return;
@@ -1754,8 +1754,8 @@ show_completed_rows_ready (GObject *source_object,
 
 			g_debug ("%s: Could not get the objects from '%s': %s",
 				G_STRFUNC,
-				source ? e_source_get_display_name (source) : "???",
-				error ? error->message : "Uknown error");
+				e_source_get_display_name (source),
+				error ? error->message : "Unknown error");
 		}
 		g_clear_error (&error);
 		return;
