@@ -135,13 +135,19 @@ preserve_charset_in_content_type (CamelMimePart *ipart,
 
 	data_wrapper = camel_medium_get_content (CAMEL_MEDIUM (opart));
 	content_type = camel_data_wrapper_get_mime_type_field (data_wrapper);
+	if (content_type)
+		camel_content_type_set_param (content_type, "charset", charset);
 
-	camel_content_type_set_param (content_type, "charset", charset);
+	/* update charset also on the part itself */
+	data_wrapper = CAMEL_DATA_WRAPPER (opart);
+	content_type = camel_data_wrapper_get_mime_type_field (data_wrapper);
+	if (content_type)
+		camel_content_type_set_param (content_type, "charset", charset);
 }
 
 static CamelMimePart *
 get_related_display_part (CamelMimePart *part,
-                            gint *out_displayid)
+                          gint *out_displayid)
 {
 	CamelMultipart *mp;
 	CamelMimePart *body_part, *display_part = NULL;
@@ -267,10 +273,10 @@ emf_parse_application_xpkcs7mime (EMFormat *emf,
 /* RFC 4155 */
 static void
 emf_parse_application_mbox (EMFormat *emf,
-                                  CamelMimePart *mime_part,
-                                  GString *part_id,
-                                  EMFormatParserInfo *info,
-                                  GCancellable *cancellable)
+                            CamelMimePart *mime_part,
+                            GString *part_id,
+                            EMFormatParserInfo *info,
+                            GCancellable *cancellable)
 {
 	CamelMimeParser *parser;
 	CamelStream *mem_stream;
@@ -345,9 +351,9 @@ emf_parse_application_mbox (EMFormat *emf,
 /* RFC 1740 */
 static void
 emf_parse_multipart_alternative (EMFormat *emf,
-                                    CamelMimePart *part,
+                                 CamelMimePart *part,
                                  GString *part_id,
-                                            EMFormatParserInfo *info,
+                                 EMFormatParserInfo *info,
                                  GCancellable *cancellable)
 {
 	CamelMultipart *mp;
@@ -426,9 +432,9 @@ emf_parse_multipart_alternative (EMFormat *emf,
 /* RFC 1740 */
 static void
 emf_parse_multipart_appledouble (EMFormat *emf,
-                                    CamelMimePart *part,
+                                 CamelMimePart *part,
                                  GString *part_id,
-                                           EMFormatParserInfo *info,
+                                 EMFormatParserInfo *info,
                                  GCancellable *cancellable)
 {
 	CamelMultipart *mp;
@@ -545,10 +551,10 @@ emf_parse_multipart_encrypted (EMFormat *emf,
 /* RFC 2046 */
 static void
 emf_parse_multipart_mixed (EMFormat *emf,
-                                CamelMimePart *part,
-                                GString *part_id,
-                                EMFormatParserInfo *info,
-                                GCancellable *cancellable)
+                           CamelMimePart *part,
+                           GString *part_id,
+                           EMFormatParserInfo *info,
+                           GCancellable *cancellable)
 {
 	CamelMultipart *mp;
 	gint i, nparts, len;
@@ -578,10 +584,10 @@ emf_parse_multipart_mixed (EMFormat *emf,
 
 static void
 emf_parse_multipart_signed (EMFormat *emf,
-                                  CamelMimePart *part,
-                                  GString *part_id,
-                                  EMFormatParserInfo *info,
-                                  GCancellable *cancellable)
+                            CamelMimePart *part,
+                            GString *part_id,
+                            EMFormatParserInfo *info,
+                            GCancellable *cancellable)
 {
 	CamelMimePart *cpart;
 	CamelMultipartSigned *mps;
@@ -685,10 +691,10 @@ emf_parse_multipart_signed (EMFormat *emf,
 /* RFC 2046 */
 static void
 emf_parse_multipart_digest (EMFormat *emf,
-                                 CamelMimePart *part,
-                                 GString *part_id,
-                                 EMFormatParserInfo *info,
-                                 GCancellable *cancellable)
+                            CamelMimePart *part,
+                            GString *part_id,
+                            EMFormatParserInfo *info,
+                            GCancellable *cancellable)
 {
 	CamelMultipart *mp;
 	gint i, nparts, len;
@@ -739,10 +745,10 @@ emf_parse_multipart_digest (EMFormat *emf,
 /* RFC 2387 */
 static void
 emf_parse_multipart_related (EMFormat *emf,
-                                    CamelMimePart *part,
-                                    GString *part_id,
-                                    EMFormatParserInfo *info,
-                                    GCancellable *cancellable)
+                             CamelMimePart *part,
+                             GString *part_id,
+                             EMFormatParserInfo *info,
+                             GCancellable *cancellable)
 {
 	CamelMultipart *mp;
 	CamelMimePart *body_part, *display_part = NULL;
@@ -786,10 +792,10 @@ emf_parse_multipart_related (EMFormat *emf,
 
 static void
 emf_parse_message_deliverystatus (EMFormat *emf,
-                                      CamelMimePart *part,
-                                      GString *part_id,
-                                      EMFormatParserInfo *info,
-                                      GCancellable *cancellable)
+                                  CamelMimePart *part,
+                                  GString *part_id,
+                                  EMFormatParserInfo *info,
+                                  GCancellable *cancellable)
 {
 	EMFormatPURI *puri;
 	gint len;
@@ -813,8 +819,8 @@ emf_parse_message_deliverystatus (EMFormat *emf,
 
 static void
 emf_parse_inlinepgp_signed (EMFormat *emf,
-                                  CamelMimePart *ipart,
-                                  GString *part_id,
+                            CamelMimePart *ipart,
+                            GString *part_id,
                             EMFormatParserInfo *info,
                             GCancellable *cancellable)
 {
@@ -1503,9 +1509,7 @@ em_format_init (EMFormat *emf)
 EMFormat *
 em_format_new (void)
 {
-	EMFormat *emf = g_object_new (EM_TYPE_FORMAT, NULL);
-
-	return emf;
+	return g_object_new (EM_TYPE_FORMAT, NULL);
 }
 
 GType
@@ -1817,7 +1821,7 @@ em_format_find_puri (EMFormat *emf,
 
 void
 em_format_class_add_handler (EMFormatClass *emfc,
-                               EMFormatHandler *handler)
+                             EMFormatHandler *handler)
 {
 	EMFormatHandler *old_handler;
 
@@ -1940,7 +1944,8 @@ em_format_parse (EMFormat *emf,
 		emf->folder = g_object_ref (folder);
 	}
 
-        /* Before the actual parsing starts, let child classes prepare themselves. */
+	/* Before the actual parsing starts,
+	 * let child classes prepare themselves. */
 	if (EM_FORMAT_GET_CLASS (emf)->preparse)
 		EM_FORMAT_GET_CLASS (emf)->preparse (emf);
 
@@ -1991,7 +1996,7 @@ em_format_parse_async (EMFormat *emf,
                        GAsyncReadyCallback callback,
                        gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	GSimpleAsyncResult *simple;
 
 	g_return_if_fail (EM_IS_FORMAT (emf));
 
@@ -2018,10 +2023,17 @@ em_format_parse_async (EMFormat *emf,
 
 	}
 
-	result = g_simple_async_result_new (G_OBJECT (emf), callback,
-					    user_data, em_format_parse_async);
-	g_simple_async_result_run_in_thread (result, emf_start_async_parser,
-					     G_PRIORITY_DEFAULT, cancellable);
+	simple = g_simple_async_result_new (
+		G_OBJECT (emf), callback,
+		user_data, em_format_parse_async);
+
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
+
+	g_simple_async_result_run_in_thread (
+		simple, emf_start_async_parser,
+		G_PRIORITY_DEFAULT, cancellable);
+
+	g_object_unref (simple);
 }
 
 void
@@ -2041,8 +2053,9 @@ em_format_parse_part_as (EMFormat *emf,
 		.force_handler = 0
 	};
 
-        /* Let everything that claims to be an attachment or inlined part to be parsed 
-         * as an attachment. The parser will decide how to display it. */
+	/* Let everything that claims to be an attachment or inlined
+	 * part to be parsed as an attachment. The parser will decide
+	 * how to display it. */
 	disposition = camel_mime_part_get_content_disposition (part);
 	if (!info->force_handler && disposition &&
 	    (g_strcmp0 (disposition->disposition, "attachment") == 0)) {
@@ -2064,7 +2077,7 @@ em_format_parse_part_as (EMFormat *emf,
 		handler = em_format_find_handler (emf, "x-evolution/message/attachment");
 		ninfo.handler = handler;
 
-                /* When this fails, something is probably very wrong...*/
+		/* When this fails, something is probably very wrong...*/
 		if (handler && handler->parse_func)
 			handler->parse_func (emf, part, part_id, &ninfo, cancellable);
 	}
