@@ -205,6 +205,8 @@ e_mail_session_handle_draft_headers (EMailSession *session,
 		G_OBJECT (session), callback, user_data,
 		e_mail_session_handle_draft_headers);
 
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
+
 	g_simple_async_result_set_op_res_gpointer (
 		simple, context, (GDestroyNotify) async_context_free);
 
@@ -356,6 +358,8 @@ e_mail_session_handle_source_headers (EMailSession *session,
 		G_OBJECT (session), callback, user_data,
 		e_mail_session_handle_source_headers);
 
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
+
 	g_simple_async_result_set_op_res_gpointer (
 		simple, context, (GDestroyNotify) async_context_free);
 
@@ -422,8 +426,7 @@ mail_session_send_to_thread (GSimpleAsyncResult *simple,
 		if (status != CAMEL_SERVICE_CONNECTED) {
 			did_connect = TRUE;
 
-			/* XXX This API does not allow for cancellation. */
-			em_utils_connect_service_sync (
+			camel_service_connect_sync (
 				service, cancellable, &error);
 
 			if (error != NULL) {
@@ -443,7 +446,7 @@ mail_session_send_to_thread (GSimpleAsyncResult *simple,
 			context->recipients, cancellable, &error);
 
 		if (did_connect)
-			em_utils_disconnect_service_sync (
+			camel_service_disconnect_sync (
 				service, error == NULL,
 				cancellable, error ? NULL : &error);
 
@@ -637,7 +640,7 @@ exit:
 
 static guint32
 get_message_size (CamelMimeMessage *message,
-		  GCancellable *cancellable)
+                  GCancellable *cancellable)
 {
 	guint32 res = 0;
 	CamelStream *null;
@@ -819,6 +822,8 @@ e_mail_session_send_to (EMailSession *session,
 		G_OBJECT (session), callback,
 		user_data, e_mail_session_send_to);
 
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
+
 	g_simple_async_result_set_op_res_gpointer (
 		simple, context, (GDestroyNotify) async_context_free);
 
@@ -890,9 +895,8 @@ e_mail_session_unsubscribe_folder_sync (EMailSession *session,
 	message = _("Unsubscribing from folder '%s'");
 	camel_operation_push_message (cancellable, message, folder_name);
 
-	/* FIXME This should take our GCancellable. */
 	success =
-		em_utils_connect_service_sync (
+		camel_service_connect_sync (
 			CAMEL_SERVICE (store), cancellable, error) &&
 		camel_subscribable_unsubscribe_folder_sync (
 			CAMEL_SUBSCRIBABLE (store),
@@ -927,6 +931,8 @@ e_mail_session_unsubscribe_folder (EMailSession *session,
 		G_OBJECT (session), callback, user_data,
 		e_mail_session_unsubscribe_folder);
 
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
+
 	g_simple_async_result_set_op_res_gpointer (
 		simple, context, (GDestroyNotify) async_context_free);
 
