@@ -108,7 +108,7 @@ vfolder_setup_exec (struct _setup_msg *m,
 	}
 
 	if (!vfolder_shutdown)
-		camel_vee_folder_set_folders ((CamelVeeFolder *) m->folder, list);
+		camel_vee_folder_set_folders ((CamelVeeFolder *) m->folder, list, cancellable);
 
 	l = list;
 	while (l) {
@@ -128,6 +128,8 @@ vfolder_setup_free (struct _setup_msg *m)
 {
 	GList *l;
 
+	camel_folder_thaw (m->folder);
+
 	g_object_unref (m->session);
 	g_object_unref (m->folder);
 	g_free (m->query);
@@ -173,6 +175,8 @@ vfolder_setup (EMailSession *session,
 	m->sources_uri = sources_uri;
 	m->sources_folder = sources_folder;
 
+	camel_folder_freeze (m->folder);
+
 	id = m->base.seq;
 	mail_msg_slow_ordered_push (m);
 
@@ -254,9 +258,9 @@ vfolder_adduri_exec (struct _adduri_msg *m,
 		while (l && !vfolder_shutdown) {
 			if (m->remove)
 				camel_vee_folder_remove_folder (
-					CAMEL_VEE_FOLDER (l->data), folder);
+					CAMEL_VEE_FOLDER (l->data), folder, cancellable);
 			else
-				camel_vee_folder_add_folder ((CamelVeeFolder *) l->data, folder);
+				camel_vee_folder_add_folder ((CamelVeeFolder *) l->data, folder, cancellable);
 			l = l->next;
 		}
 		g_object_unref (folder);
@@ -272,8 +276,8 @@ static void
 vfolder_adduri_free (struct _adduri_msg *m)
 {
 	g_object_unref (m->session);
-	g_list_foreach (m->folders, (GFunc) g_object_unref, NULL);
-	g_list_free (m->folders);
+	g_list_foreach (m->folders, (GFunc) camel_folder_thaw, NULL);
+	g_list_free_full (m->folders, g_object_unref);
 	g_free (m->uri);
 }
 
@@ -301,6 +305,8 @@ vfolder_adduri (EMailSession *session,
 	m->uri = g_strdup (uri);
 	m->remove = remove;
 
+	g_list_foreach (m->folders, (GFunc) camel_folder_freeze, NULL);
+
 	id = m->base.seq;
 	mail_msg_slow_ordered_push (m);
 
@@ -877,27 +883,30 @@ store_folder_deleted_cb (CamelStore *store,
 	gchar *user;
 
 	d(printf("Folder deleted: %s\n", info->name));
-	store = store;
+
+	/* Unmatched folder doesn't have any rule */
+	if (g_strcmp0 (CAMEL_UNMATCHED_NAME, info->full_name) == 0)
+		return;
 
 	/* Warning not thread safe, but might be enough */
-
 	G_LOCK (vfolder);
 
 	/* delete it from our list */
 	rule = e_rule_context_find_rule ((ERuleContext *) context, info->full_name, NULL);
 	if (rule) {
 		const gchar *config_dir;
+		EMailSession *session = E_MAIL_SESSION (camel_service_get_session (CAMEL_SERVICE (store)));
 
 		/* We need to stop listening to removed events,
 		 * otherwise we'll try and remove it again. */
 		g_signal_handlers_disconnect_matched (
-			context, G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
-			0, 0, NULL, context_rule_removed, context);
+			context, G_SIGNAL_MATCH_FUNC,
+			0, 0, NULL, context_rule_removed, NULL);
 		e_rule_context_remove_rule ((ERuleContext *) context, rule);
 		g_object_unref (rule);
 		g_signal_connect (
 			context, "rule_removed",
-			G_CALLBACK (context_rule_removed), context);
+			G_CALLBACK (context_rule_removed), session);
 
 		config_dir = mail_session_get_config_dir ();
 		user = g_build_filename (config_dir, "vfolders.xml", NULL);
