@@ -32,7 +32,6 @@
 
 #include "em-format-html.h"
 
-
 #define d(x)
 
 #define E_HTTP_REQUEST_GET_PRIVATE(obj) \
@@ -168,8 +167,8 @@ http_request_finished (SoupRequest *request,
 
 static gssize
 copy_stream_to_stream (CamelStream *input,
-		       GMemoryInputStream *output,
-		       GCancellable *cancellable)
+                       GMemoryInputStream *output,
+                       GCancellable *cancellable)
 {
 	gchar *buff;
 	gssize read_len = 0;
@@ -195,7 +194,7 @@ copy_stream_to_stream (CamelStream *input,
 
 static void
 quit_main_loop (GCancellable *cancellable,
-	        GMainLoop *loop)
+                GMainLoop *loop)
 {
 	if (g_main_loop_is_running (loop)) {
 		g_main_loop_quit (loop);
@@ -364,7 +363,7 @@ handle_http_request (GSimpleAsyncResult *res,
 		g_cancellable_disconnect (cancellable, id);
 
 		/* Wait until all asynchronous operations are finished working
-		   with the 'data' structure so that it's not free'd too early. */
+		 * with the 'data' structure so that it's not free'd too early. */
 		e_flag_wait (data.flag);
 		e_flag_free (data.flag);
 
@@ -431,7 +430,7 @@ http_request_send_async (SoupRequest *request,
                          gpointer user_data)
 {
 	EHTTPRequest *ehr;
-	GSimpleAsyncResult *result;
+	GSimpleAsyncResult *simple;
 	gchar *mail_uri;
 	SoupURI *uri;
 	const gchar *enc;
@@ -465,10 +464,17 @@ http_request_send_async (SoupRequest *request,
 	/* Make sure the formatter lives until we are finished here */
 	g_object_ref (ehr->priv->efh);
 
-	result = g_simple_async_result_new (G_OBJECT (request), callback,
-			user_data, http_request_send_async);
-	g_simple_async_result_run_in_thread (result, handle_http_request,
-			G_PRIORITY_DEFAULT, cancellable);
+	simple = g_simple_async_result_new (
+		G_OBJECT (request), callback,
+		user_data, http_request_send_async);
+
+	g_simple_async_result_set_check_cancellable (simple, cancellable);
+
+	g_simple_async_result_run_in_thread (
+		simple, handle_http_request,
+		G_PRIORITY_DEFAULT, cancellable);
+
+	g_object_unref (simple);
 
 	g_hash_table_destroy (query);
 }
@@ -481,7 +487,6 @@ http_request_send_finish (SoupRequest *request,
 	GInputStream *stream;
 
 	stream = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result));
-	g_object_unref (result);
 
 	/* Reset the stream before passing it back to webkit */
 	if (stream && G_IS_SEEKABLE (stream))
