@@ -23,7 +23,6 @@
 #include <config.h>
 #endif
 
-
 #include "e-mail-display.h"
 
 #include <glib/gi18n.h>
@@ -391,6 +390,7 @@ mail_display_link_clicked (WebKitWebView *web_view,
 		if (g_file_test (filename, G_FILE_TEST_IS_DIR)) {
 			webkit_web_policy_decision_ignore (policy_decision);
 			webkit_network_request_set_uri (request, "about:blank");
+			g_free (filename);
 			return TRUE;
 		}
 
@@ -461,7 +461,6 @@ mail_display_resource_requested (WebKitWebView *web_view,
 	const gchar *uri = webkit_network_request_get_uri (request);
 
 	if (!formatter) {
-		webkit_network_request_set_uri (request, "about:blank");
 		return;
 	}
 
@@ -1200,8 +1199,8 @@ mail_display_frame_created (WebKitWebView *web_view,
 
 static void
 mail_display_set_fonts (EWebView *web_view,
-			PangoFontDescription **monospace,
-			PangoFontDescription **variable)
+                        PangoFontDescription **monospace,
+                        PangoFontDescription **variable)
 {
 	EMailDisplay *display = E_MAIL_DISPLAY (web_view);
 	gboolean use_custom_font;
