@@ -198,13 +198,13 @@ e_mail_reader_delete_folder (EMailReader *reader,
 	EShell *shell;
 	EAlertSink *alert_sink;
 	CamelStore *parent_store;
+	CamelProvider *provider;
 	MailFolderCache *folder_cache;
 	GtkWindow *parent = e_shell_get_active_window (NULL);
 	GtkWidget *dialog;
 	gboolean store_is_local;
 	const gchar *display_name;
 	const gchar *full_name;
-	const gchar *uid;
 	CamelFolderInfoFlags flags = 0;
 	gboolean have_flags;
 
@@ -214,9 +214,9 @@ e_mail_reader_delete_folder (EMailReader *reader,
 	full_name = camel_folder_get_full_name (folder);
 	display_name = camel_folder_get_display_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
+	provider = camel_service_get_provider (CAMEL_SERVICE (parent_store));
 
-	uid = camel_service_get_uid (CAMEL_SERVICE (parent_store));
-	store_is_local = (g_strcmp0 (uid, E_MAIL_SESSION_LOCAL_UID) == 0);
+	store_is_local = (provider->flags & CAMEL_PROVIDER_IS_LOCAL) != 0;
 
 	backend = e_mail_reader_get_backend (reader);
 	session = e_mail_backend_get_session (backend);
@@ -351,6 +351,8 @@ copy_tree_state (EMailReader *src_reader,
 	if (state)
 		e_tree_set_state (E_TREE (des_mlist), state);
 	g_free (state);
+
+	message_list_set_search (MESSAGE_LIST (des_mlist), MESSAGE_LIST (src_mlist)->search);
 }
 
 guint
@@ -423,15 +425,23 @@ e_mail_reader_open_selected (EMailReader *reader)
 	for (ii = 0; ii < views->len; ii++) {
 		const gchar *uid = views->pdata[ii];
 		GtkWidget *browser;
+		MessageList *ml;
 
 		browser = e_mail_browser_new (backend, folder, uid,
 				EM_FORMAT_WRITE_MODE_NORMAL);
+
 		e_mail_reader_set_folder (E_MAIL_READER (browser), folder);
 		e_mail_reader_set_message (E_MAIL_READER (browser), uid);
+
+		ml = MESSAGE_LIST (e_mail_reader_get_message_list (E_MAIL_READER (browser)));
+		message_list_freeze (ml);
+
 		copy_tree_state (reader, E_MAIL_READER (browser));
 		e_mail_reader_set_group_by_threads (
 			E_MAIL_READER (browser),
 			e_mail_reader_get_group_by_threads (reader));
+
+		message_list_thaw (ml);
 		gtk_widget_show (browser);
 	}
 
@@ -481,10 +491,15 @@ printing_done_cb (EMailPrinter *printer,
 	/* Set activity as completed, and keep it displayed for a few seconds
 	 * so that user can actually see the the printing was sucesfully finished. */
 	e_activity_set_state (activity, E_ACTIVITY_COMPLETED);
+
+	/* We can't destroy the printer and associated WebKitWebView directly from
+	 * here, because this callback is a handler of a WebKit's signal. This
+	 * will destroy the printer later, together with the activity */
+	g_object_set_data_full (G_OBJECT (activity),
+		"printer", printer, (GDestroyNotify) g_object_unref);
+
 	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, 3,
 		(GSourceFunc) destroy_printing_activity, activity, NULL);
-
-	g_object_unref (printer);
 }
 
 void
