@@ -67,7 +67,8 @@ EMailReaderHeader *
 gchar *		e_mail_reader_header_to_xml	(EMailReaderHeader *header);
 void		e_mail_reader_header_free	(EMailReaderHeader *header);
 
-void		e_mail_reader_connect_headers	(EMailReader *reader);
+void		e_mail_reader_connect_headers	(EMailReader *reader,
+						 EMFormat *emf);
 
 G_END_DECLS
 
