@@ -74,9 +74,6 @@ struct _EMFolderTreeModelPrivate {
 
 	/* CamelStore -> EMFolderTreeStoreInfo */
 	GHashTable *store_index;
-
-	/* URI -> GtkTreeRowReference */
-	GHashTable *uri_index;
 };
 
 enum {
@@ -321,7 +318,6 @@ folder_tree_model_finalize (GObject *object)
 	priv = EM_FOLDER_TREE_MODEL_GET_PRIVATE (object);
 
 	g_hash_table_destroy (priv->store_index);
-	g_hash_table_destroy (priv->uri_index);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -335,7 +331,6 @@ folder_tree_model_constructed (GObject *object)
 		G_TYPE_POINTER,  /* store object */
 		G_TYPE_STRING,   /* full name */
 		G_TYPE_STRING,   /* icon name */
-		G_TYPE_STRING,   /* uri */
 		G_TYPE_UINT,     /* unread count */
 		G_TYPE_UINT,     /* flags */
 		G_TYPE_BOOLEAN,  /* is a store node */
@@ -477,21 +472,14 @@ static void
 em_folder_tree_model_init (EMFolderTreeModel *model)
 {
 	GHashTable *store_index;
-	GHashTable *uri_index;
 
 	store_index = g_hash_table_new_full (
 		g_direct_hash, g_direct_equal,
 		(GDestroyNotify) NULL,
 		(GDestroyNotify) store_info_free);
 
-	uri_index = g_hash_table_new_full (
-		g_str_hash, g_str_equal,
-		(GDestroyNotify) g_free,
-		(GDestroyNotify) gtk_tree_row_reference_free);
-
 	model->priv = EM_FOLDER_TREE_MODEL_GET_PRIVATE (model);
 	model->priv->store_index = store_index;
-	model->priv->uri_index = uri_index;
 }
 
 EMFolderTreeModel *
@@ -624,7 +612,7 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
                                       CamelFolderInfo *fi,
                                       gint fully_loaded)
 {
-	GtkTreeRowReference *uri_row, *path_row;
+	GtkTreeRowReference *path_row;
 	GtkTreeStore *tree_store;
 	MailFolderCache *folder_cache;
 	EMailSession *session;
@@ -664,15 +652,11 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 			(CAMEL_FOLDER_NOCHILDREN | CAMEL_FOLDER_NOINFERIORS));
 
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), iter);
-	uri_row = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
-	path_row = gtk_tree_row_reference_copy (uri_row);
+	path_row = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
 	gtk_tree_path_free (path);
 
 	uri = e_mail_folder_uri_build (si->store, fi->full_name);
 
-	/* Hash table takes ownership of the URI string. */
-	g_hash_table_insert (
-		model->priv->uri_index, uri, uri_row);
 	g_hash_table_insert (
 		si->full_hash, g_strdup (fi->full_name), path_row);
 
@@ -760,7 +744,6 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 		COL_POINTER_CAMEL_STORE, si->store,
 		COL_STRING_FULL_NAME, fi->full_name,
 		COL_STRING_ICON_NAME, icon_name,
-		COL_STRING_URI, uri,
 		COL_UINT_FLAGS, flags,
 		COL_BOOL_IS_STORE, FALSE,
 		COL_BOOL_IS_FOLDER, TRUE,
@@ -769,6 +752,9 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 		COL_BOOL_IS_DRAFT, folder_is_drafts,
 		-1);
 
+	g_free (uri);
+	uri = NULL;
+
 	target = em_event_target_new_custom_icon (
 		em_event_peek (), tree_store, iter,
 		fi->full_name, EM_EVENT_CUSTOM_ICON);
@@ -793,7 +779,6 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model,
 			COL_BOOL_LOAD_SUBDIRS, FALSE,
 			COL_BOOL_IS_STORE, FALSE,
 			COL_BOOL_IS_FOLDER, FALSE,
-			COL_STRING_URI, NULL,
 			COL_UINT_UNREAD, 0,
 			COL_UINT_UNREAD_LAST_SEL, 0,
 			COL_BOOL_IS_DRAFT, FALSE,
@@ -1050,24 +1035,22 @@ em_folder_tree_model_add_store (EMFolderTreeModel *model,
 		COL_STRING_FULL_NAME, NULL,
 		COL_BOOL_LOAD_SUBDIRS, TRUE,
 		COL_BOOL_IS_STORE, TRUE,
-		COL_STRING_URI, uri,
 		-1);
 
+	g_free (uri);
+
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
 	reference = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
 
 	si = g_new0 (EMFolderTreeModelStoreInfo, 1);
 	si->store = g_object_ref (store);
-	si->row = gtk_tree_row_reference_copy (reference);
+	si->row = reference;  /* takes ownership */
 	si->full_hash = g_hash_table_new_full (
 		g_str_hash, g_str_equal,
 		(GDestroyNotify) g_free,
 		(GDestroyNotify) gtk_tree_row_reference_free);
 	g_hash_table_insert (model->priv->store_index, store, si);
 
-	/* Transfer ownership of the URI and GtkTreeRowReference. */
-	g_hash_table_insert (model->priv->uri_index, uri, reference);
-
 	/* Each store has folders, but we don't load them until
 	 * the user demands them. */
 	root = iter;
@@ -1080,7 +1063,6 @@ em_folder_tree_model_add_store (EMFolderTreeModel *model,
 		COL_BOOL_LOAD_SUBDIRS, FALSE,
 		COL_BOOL_IS_STORE, FALSE,
 		COL_BOOL_IS_FOLDER, FALSE,
-		COL_STRING_URI, NULL,
 		COL_UINT_UNREAD, 0,
 		COL_UINT_UNREAD_LAST_SEL, 0,
 		COL_BOOL_IS_DRAFT, FALSE,
@@ -1145,7 +1127,7 @@ em_folder_tree_model_remove_folders (EMFolderTreeModel *model,
                                      EMFolderTreeModelStoreInfo *si,
                                      GtkTreeIter *toplevel)
 {
-	gchar *uri, *full_name;
+	gchar *full_name;
 	gboolean is_store, go;
 	GtkTreeIter iter;
 
@@ -1161,16 +1143,12 @@ em_folder_tree_model_remove_folders (EMFolderTreeModel *model,
 
 	gtk_tree_model_get (
 		GTK_TREE_MODEL (model), toplevel,
-		COL_STRING_URI, &uri,
 		COL_STRING_FULL_NAME, &full_name,
 		COL_BOOL_IS_STORE, &is_store, -1);
 
 	if (full_name != NULL)
 		g_hash_table_remove (si->full_hash, full_name);
 
-	if (uri != NULL)
-		g_hash_table_remove (model->priv->uri_index, uri);
-
 	gtk_tree_store_remove ((GtkTreeStore *) model, toplevel);
 
 	/* Freeing the GtkTreeRowReference in the store info may finalize
@@ -1183,7 +1161,6 @@ em_folder_tree_model_remove_folders (EMFolderTreeModel *model,
 	}
 
 	g_free (full_name);
-	g_free (uri);
 }
 
 gboolean
@@ -1268,14 +1245,46 @@ GtkTreeRowReference *
 em_folder_tree_model_lookup_uri (EMFolderTreeModel *model,
                                  const gchar *folder_uri)
 {
-	GtkTreeRowReference *reference;
+	GtkTreeRowReference *reference = NULL;
+	EMFolderTreeModelStoreInfo *si;
+	EMailSession *session;
+	CamelStore *store = NULL;
+	gchar *folder_name = NULL;
+	GError *error = NULL;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE_MODEL (model), NULL);
 	g_return_val_if_fail (folder_uri != NULL, NULL);
 
-	reference = g_hash_table_lookup (model->priv->uri_index, folder_uri);
+	session = em_folder_tree_model_get_session (model);
+	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
 
-	return gtk_tree_row_reference_valid (reference) ? reference : NULL;
+	e_mail_folder_uri_parse (
+		CAMEL_SESSION (session),
+		folder_uri, &store, &folder_name, &error);
+
+	if (error != NULL) {
+		g_warn_if_fail (store == NULL);
+		g_warn_if_fail (folder_name == NULL);
+		g_warning ("%s: %s", G_STRFUNC, error->message);
+		g_error_free (error);
+		return NULL;
+	}
+
+	g_return_val_if_fail (CAMEL_IS_STORE (store), NULL);
+	g_return_val_if_fail (folder_name != NULL, NULL);
+
+	si = g_hash_table_lookup (model->priv->store_index, store);
+
+	if (si != NULL)
+		reference = g_hash_table_lookup (si->full_hash, folder_name);
+
+	if (!gtk_tree_row_reference_valid (reference))
+		reference = NULL;
+
+	g_object_unref (store);
+	g_free (folder_name);
+
+	return reference;
 }
 
 void
