@@ -808,6 +808,7 @@ folder_tree_render_icon (GtkTreeViewColumn *column,
 	gboolean is_selected;
 	gboolean is_drafts = FALSE;
 	gboolean is_drag_dest = FALSE;
+	guint32 fi_flags = 0;
 
 	gtk_tree_model_get (
 		model, iter,
@@ -815,6 +816,7 @@ folder_tree_render_icon (GtkTreeViewColumn *column,
 		COL_UINT_UNREAD_LAST_SEL, &old_unread,
 		COL_UINT_UNREAD, &unread,
 		COL_BOOL_IS_DRAFT, &is_drafts,
+		COL_UINT_FLAGS, &fi_flags,
 		-1);
 
 	if (icon_name == NULL)
@@ -850,7 +852,7 @@ folder_tree_render_icon (GtkTreeViewColumn *column,
 	icon = g_themed_icon_new (icon_name);
 
 	/* Show an emblem if there's new mail. */
-	if (!is_selected && unread > old_unread && !is_drafts) {
+	if (!is_selected && unread > old_unread && !is_drafts && !(fi_flags & CAMEL_FOLDER_VIRTUAL)) {
 		GIcon *temp_icon;
 		GEmblem *emblem;
 
@@ -1968,10 +1970,10 @@ fail:
 
 static gboolean
 ask_drop_folder (EMFolderTree *folder_tree,
-		 const gchar *src_folder_uri,
-		 const gchar *des_full_name,
-		 CamelStore *des_store,
-		 gboolean is_move)
+                 const gchar *src_folder_uri,
+                 const gchar *des_full_name,
+                 CamelStore *des_store,
+                 gboolean is_move)
 {
 	const gchar *key = is_move ? "prompt-on-folder-drop-move" : "prompt-on-folder-drop-copy";
 	EMailSession *session;
@@ -2292,6 +2294,7 @@ tree_drag_data_received (GtkWidget *widget,
 			      gdk_drag_context_get_selected_action (context) == GDK_ACTION_MOVE)) {
 		gtk_drag_finish (context, FALSE, FALSE, GDK_CURRENT_TIME);
 		gtk_tree_path_free (dest_path);
+		g_free (full_name);
 		return;
 	}
 
