@@ -247,12 +247,11 @@ select_source (GtkWidget *list,
 	GtkTreeIter iter;
 
 	gtk_tree_view_get_cursor (data->list, &path, &column);
-	if (path && gtk_tree_model_get_iter (GTK_TREE_MODEL (data->model), &iter, path))
-		gtk_tree_model_get (GTK_TREE_MODEL (data->model), &iter, 0, &data->current, -1);
-	else
-		data->current = NULL;
+	gtk_tree_model_get_iter (GTK_TREE_MODEL (data->model), &iter, path);
 	gtk_tree_path_free (path);
 
+	gtk_tree_model_get (GTK_TREE_MODEL (data->model), &iter, 0, &data->current, -1);
+
 	set_sensitive (data);
 }
 
@@ -434,7 +433,7 @@ get_widget (EFilterRule *fr,
 	builder = gtk_builder_new ();
 	e_load_ui_builder_definition (builder, "mail-dialogs.ui");
 
-        frame = e_builder_get_widget(builder, "vfolder_source_frame");
+	frame = e_builder_get_widget(builder, "vfolder_source_frame");
 
 	g_object_set_data_full((GObject *)frame, "data", data, g_free);
 
