@@ -202,19 +202,40 @@ cal_shell_view_date_navigator_selection_changed_cb (ECalShellView *cal_shell_vie
 	gnome_calendar_notify_dates_shown_changed (calendar);
 }
 
-static void
+static gboolean
 cal_shell_view_date_navigator_scroll_event_cb (ECalShellView *cal_shell_view,
                                                GdkEventScroll *event,
                                                ECalendar *date_navigator)
 {
 	ECalendarItem *calitem;
 	GDate start_date, end_date;
+	GdkScrollDirection direction;
 
 	calitem = date_navigator->calitem;
 	if (!e_calendar_item_get_selection (calitem, &start_date, &end_date))
-		return;
+		return FALSE;
 
-	switch (event->direction) {
+	direction = event->direction;
+
+	#if GTK_CHECK_VERSION(3,3,18)
+	if (direction == GDK_SCROLL_SMOOTH) {
+		static gdouble total_delta_y = 0.0;
+
+		total_delta_y += event->delta_y;
+
+		if (total_delta_y >= 1.0) {
+			total_delta_y = 0.0;
+			direction = GDK_SCROLL_DOWN;
+		} else if (total_delta_y <= -1.0) {
+			total_delta_y = 0.0;
+			direction = GDK_SCROLL_UP;
+		} else {
+			return FALSE;
+		}
+	}
+	#endif
+
+	switch (direction) {
 		case GDK_SCROLL_UP:
 			g_date_subtract_months (&start_date, 1);
 			g_date_subtract_months (&end_date, 1);
@@ -226,7 +247,7 @@ cal_shell_view_date_navigator_scroll_event_cb (ECalShellView *cal_shell_view,
 			break;
 
 		default:
-			g_return_if_reached ();
+			g_return_val_if_reached (FALSE);
 	}
 
 	/* XXX Does ECalendarItem emit a signal for this?  If so, maybe
@@ -235,6 +256,8 @@ cal_shell_view_date_navigator_scroll_event_cb (ECalShellView *cal_shell_view,
 
 	cal_shell_view_date_navigator_selection_changed_cb (
 		cal_shell_view, calitem);
+
+	return TRUE;
 }
 
 static void
@@ -689,8 +712,8 @@ e_cal_shell_view_private_dispose (ECalShellView *cal_shell_view)
 
 	e_cal_shell_view_search_stop (cal_shell_view);
 
-	/* Calling calendar's save state from here,
-	 * because it is too late in its dispose. */
+	/* Calling ECalShellContent's save state from here,
+	 * because it is too late in its own dispose(). */
 	if (priv->cal_shell_content != NULL)
 		e_cal_shell_content_save_state (priv->cal_shell_content);
 
@@ -861,7 +884,7 @@ e_cal_shell_view_transfer_item_to (ECalShellView *cal_shell_view,
 	gboolean success;
 	const gchar *uid;
 	EShell *shell;
-	EShellContent *shell_content;	
+	EShellContent *shell_content;
 	gboolean is_src_local_cal, is_dest_local_cal;
 
 	/* XXX This function should be split up into
@@ -881,8 +904,8 @@ e_cal_shell_view_transfer_item_to (ECalShellView *cal_shell_view,
 	is_dest_local_cal = g_str_has_prefix (e_client_get_uri(E_CLIENT (destination_client)), "local:");
 
 	shell = e_shell_get_default ();
-	shell_content = e_shell_view_get_shell_content(E_SHELL_VIEW (cal_shell_view));
-	if(!e_shell_get_online(shell) && ((!is_src_local_cal && remove) || !is_dest_local_cal))
+	shell_content = e_shell_view_get_shell_content (E_SHELL_VIEW (cal_shell_view));
+	if (!e_shell_get_online (shell) && ((!is_src_local_cal && remove) || !is_dest_local_cal))
 	{
 		e_alert_submit (
 			E_ALERT_SINK (shell_content),
@@ -1181,7 +1204,7 @@ cal_searching_get_search_range_years (ECalShellView *cal_shell_view)
 
 static gint
 cal_time_t_ptr_compare (gconstpointer a,
-			gconstpointer b)
+                        gconstpointer b)
 {
 	const time_t *ta = a, *tb = b;
 
@@ -1220,9 +1243,9 @@ cal_searching_instances_done_cb (gpointer user_data)
 
 static gboolean
 cal_searching_got_instance_cb (ECalComponent *comp,
-			       time_t instance_start,
-			       time_t instance_end,
-			       gpointer user_data)
+                               time_t instance_start,
+                               time_t instance_end,
+                               gpointer user_data)
 {
 	struct GenerateInstancesData *gid = user_data;
 	ECalShellViewPrivate *priv;
@@ -1267,8 +1290,8 @@ cal_searching_got_instance_cb (ECalComponent *comp,
 
 static void
 cal_search_get_object_list_cb (GObject *source,
-			       GAsyncResult *result,
-			       gpointer user_data)
+                               GAsyncResult *result,
+                               gpointer user_data)
 {
 	ECalClient *client = E_CAL_CLIENT (source);
 	ECalShellView *cal_shell_view = user_data;
@@ -1369,7 +1392,7 @@ cal_searching_check_candidates (ECalShellView *cal_shell_view)
 
 static void
 cal_searching_update_alert (ECalShellView *cal_shell_view,
-			    const gchar *message)
+                            const gchar *message)
 {
 	ECalShellViewPrivate *priv;
 	EShellContent *shell_content;
@@ -1532,7 +1555,7 @@ cal_iterate_searching (ECalShellView *cal_shell_view)
 
 void
 e_cal_shell_view_search_events (ECalShellView *cal_shell_view,
-				gboolean search_forward)
+                                gboolean search_forward)
 {
 	ECalShellViewPrivate *priv = cal_shell_view->priv;
 	ECalShellContent *cal_shell_content;
