@@ -134,9 +134,9 @@ create_memo_sources (EShellBackend *shell_backend,
 
 			e_shell_settings_set_string (
 				shell_settings, "cal-primary-memo-list",
-				e_source_peek_uid (source));
+				e_source_get_uid (source));
 
-			link.data = (gpointer) e_source_peek_uid (source);
+			link.data = (gpointer) e_source_get_uid (source);
 			link.next = NULL;
 
 			e_memo_shell_backend_set_selected_memo_lists (
