@@ -149,12 +149,6 @@ static void
 mail_config_web_view_realize (GtkWidget *widget,
                               EMailConfigWebView *extension)
 {
-	g_object_bind_property (
-		extension->shell_settings,
-		"mail-show-animated-images",
-		widget, "animate",
-		G_BINDING_SYNC_CREATE);
-
 	g_object_bind_property (
 		extension->shell_settings,
 		"composer-inline-spelling",
