@@ -33,11 +33,14 @@
 #include <shell/e-shell.h>
 #include <shell/e-shell-window.h>
 
+#ifdef WITH_CAPPLET
 #include <capplet/settings/mail-capplet-shell.h>
+#endif
 
 #include <composer/e-msg-composer.h>
 
 #include <widgets/misc/e-preferences-window.h>
+#include <widgets/misc/e-signature-editor.h>
 #include <widgets/misc/e-web-view.h>
 
 #include <libemail-engine/e-mail-folder-utils.h>
@@ -361,7 +364,6 @@ mail_shell_backend_window_added_cb (GtkApplication *application,
 
 	/* This applies to both the composer and signature editor. */
 	if (GTKHTML_IS_EDITOR (window)) {
-		EShellSettings *shell_settings;
 		GList *spell_languages;
 		gboolean active = TRUE;
 
@@ -370,14 +372,19 @@ mail_shell_backend_window_added_cb (GtkApplication *application,
 			GTKHTML_EDITOR (window), spell_languages);
 		g_list_free (spell_languages);
 
-		shell_settings = e_shell_get_shell_settings (shell);
+		if (!E_IS_SIGNATURE_EDITOR (window) ||
+		    !e_signature_editor_get_editing_old (E_SIGNATURE_EDITOR (window))) {
+			EShellSettings *shell_settings;
 
-		/* Express mode does not honor this setting. */
-		if (!e_shell_get_express_mode (shell))
-			active = e_shell_settings_get_boolean (
-				shell_settings, "composer-format-html");
+			shell_settings = e_shell_get_shell_settings (shell);
 
-		gtkhtml_editor_set_html_mode (GTKHTML_EDITOR (window), active);
+			/* Express mode does not honor this setting. */
+			if (!e_shell_get_express_mode (shell))
+				active = e_shell_settings_get_boolean (
+					shell_settings, "composer-format-html");
+
+			gtkhtml_editor_set_html_mode (GTKHTML_EDITOR (window), active);
+		}
 	}
 
 	if (E_IS_MSG_COMPOSER (window)) {
@@ -418,11 +425,15 @@ static void
 mail_shell_backend_constructed (GObject *object)
 {
 	EShell *shell;
+	EShellSettings *shell_settings;
 	EShellBackend *shell_backend;
+	EMailSession *mail_session;
+	CamelService *vstore;
 	GtkWidget *preferences_window;
 
 	shell_backend = E_SHELL_BACKEND (object);
 	shell = e_shell_backend_get_shell (shell_backend);
+	shell_settings = e_shell_get_shell_settings (shell);
 
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (e_mail_shell_backend_parent_class)->constructed (object);
@@ -492,6 +503,13 @@ mail_shell_backend_constructed (GObject *object)
 		NULL,
 		em_network_prefs_new,
 		500);
+
+	mail_session = e_mail_backend_get_session (E_MAIL_BACKEND (object));
+	vstore = camel_session_get_service (CAMEL_SESSION (mail_session), E_MAIL_SESSION_VFOLDER_UID);
+	g_object_bind_property (
+		shell_settings, "mail-enable-unmatched-search-folder",
+		vstore, "unmatched-enabled",
+		G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 }
 
 static void
@@ -693,6 +711,10 @@ void
 e_mail_shell_backend_new_account (EMailShellBackend *mail_shell_backend,
                                   GtkWindow *parent)
 {
+#ifdef WITH_CAPPLET
+	EShell *shell;
+	EShellBackend *shell_backend;
+#endif /* WITH_CAPPLET */
 	EMailShellBackendPrivate *priv;
 
 	g_return_if_fail (mail_shell_backend != NULL);
@@ -700,41 +722,46 @@ e_mail_shell_backend_new_account (EMailShellBackend *mail_shell_backend,
 
 	priv = mail_shell_backend->priv;
 
-	if (priv->assistant) {
+	if (priv->assistant != NULL) {
 		gtk_window_present (GTK_WINDOW (priv->assistant));
-	} else {
-		EMAccountEditor *emae;
-		EShell *shell;
-
-		shell = e_shell_backend_get_shell (E_SHELL_BACKEND (mail_shell_backend));
-
-		if (!e_shell_get_express_mode (shell)) {
-			/** @HookPoint-EMConfig: New Mail Account Assistant
-			 * @Id: org.gnome.evolution.mail.config.accountAssistant
-			 * @Type: E_CONFIG_ASSISTANT
-			 * @Class: org.gnome.evolution.mail.config:1.0
-			 * @Target: EMConfigTargetAccount
-			 *
-			 * The new mail account assistant.
-			 */
-			emae = em_account_editor_new (
-				NULL, EMAE_ASSISTANT, E_MAIL_BACKEND (mail_shell_backend),
-				"org.gnome.evolution.mail.config.accountAssistant");
-			e_config_create_window (
-				E_CONFIG (emae->config), NULL,
-				_("Evolution Account Assistant"));
-			priv->assistant = E_CONFIG (emae->config)->window;
-			g_object_set_data_full (
-				G_OBJECT (priv->assistant), "AccountEditor",
-				emae, (GDestroyNotify) g_object_unref);
-		} else {
-			priv->assistant = mail_capplet_shell_new (0, TRUE, FALSE);
-		}
-
-		g_object_add_weak_pointer (G_OBJECT (priv->assistant), &priv->assistant);
-		gtk_window_set_transient_for (GTK_WINDOW (priv->assistant), parent);
-		gtk_widget_show (priv->assistant);
+		return;
 	}
+
+#ifdef WITH_CAPPLET
+	shell_backend = E_SHELL_BACKEND (mail_shell_backend);
+	shell = e_shell_backend_get_shell (shell_backend);
+
+	if (e_shell_get_express_mode (shell))
+		priv->assistant = mail_capplet_shell_new (0, TRUE, FALSE);
+#endif /* WITH_CAPPLET */
+
+	if (priv->assistant == NULL) {
+		EMAccountEditor *emae;
+
+		/** @HookPoint-EMConfig: New Mail Account Assistant
+		 * @Id: org.gnome.evolution.mail.config.accountAssistant
+		 * @Type: E_CONFIG_ASSISTANT
+		 * @Class: org.gnome.evolution.mail.config:1.0
+		 * @Target: EMConfigTargetAccount
+		 *
+		 * The new mail account assistant.
+		 */
+		emae = em_account_editor_new (
+			NULL, EMAE_ASSISTANT, E_MAIL_BACKEND (mail_shell_backend),
+			"org.gnome.evolution.mail.config.accountAssistant");
+		e_config_create_window (
+			E_CONFIG (emae->config), NULL,
+			_("Evolution Account Assistant"));
+		priv->assistant = E_CONFIG (emae->config)->window;
+		g_object_set_data_full (
+			G_OBJECT (priv->assistant), "AccountEditor",
+			emae, (GDestroyNotify) g_object_unref);
+	}
+
+	g_object_add_weak_pointer (
+		G_OBJECT (priv->assistant), &priv->assistant);
+	gtk_window_set_transient_for (GTK_WINDOW (priv->assistant), parent);
+	gtk_widget_show (priv->assistant);
 }
 
 void
