@@ -32,7 +32,6 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtkhtml/gtkhtml.h>
 #include <libecal/e-cal-client.h>
 #include <libecal/e-cal-component.h>
 #include <libedataserver/e-account.h>
@@ -1062,18 +1061,16 @@ text_contains_nonwhitespace (const gchar *text,
 static gchar *
 get_selected_text (EMailReader *reader)
 {
-	EMFormatHTML *formatter;
-	EWebView *web_view;
+	EMailDisplay *display;
 	gchar *text = NULL;
 	gint len;
 
-	formatter = e_mail_reader_get_formatter (reader);
-	web_view = em_format_html_get_web_view (formatter);
+	display = e_mail_reader_get_mail_display (reader);
 
-	if (!e_web_view_is_selection_active (web_view))
+	if (!e_web_view_is_selection_active (E_WEB_VIEW (display)))
 		return NULL;
 
-	text = gtk_html_get_selection_plain_text (GTK_HTML (web_view), &len);
+	text = e_mail_display_get_selection_plain_text (display, &len);
 
 	if (text == NULL || !text_contains_nonwhitespace (text, len)) {
 		g_free (text);
