@@ -34,10 +34,8 @@
 #include <libedataserverui/e-categories-editor.h>
 
 #define EVOLUTION_COPYRIGHT \
-	"Copyright \xC2\xA9 1999 - 2008 Novell, Inc. and Others"
-
-#define EVOLUTION_WEBSITE \
-	"http://www.gnome.org/projects/evolution/"
+	"Copyright \xC2\xA9 1999 - 2008 Novell, Inc. and Others\n" \
+	"Copyright \xC2\xA9 2008 - 2012 The Evolution Team"
 
 /* Authors and Documenters
  *
@@ -652,12 +650,13 @@ action_about_cb (GtkAction *action,
 		"version", VERSION,
 		"copyright", EVOLUTION_COPYRIGHT,
 		"comments", _("Groupware Suite"),
-		"website", EVOLUTION_WEBSITE,
+		"website", PACKAGE_URL,
 		"website-label", _("Evolution Website"),
 		"authors", authors,
 		"documenters", documenters,
 		"translator-credits", translator_credits,
 		"logo-icon-name", "evolution",
+	        "license-type", GTK_LICENSE_GPL_2_0,
 		NULL);
 }
 
@@ -989,9 +988,10 @@ action_quick_reference_cb (GtkAction *action,
                            EShellWindow *shell_window)
 {
 	const gchar * const *language_names;
+	gboolean app_launched = FALSE;
 
 	language_names = g_get_language_names ();
-	while (*language_names != NULL) {
+	while (*language_names != NULL && !app_launched) {
 		const gchar *language = *language_names++;
 		gchar *filename;
 
@@ -1013,7 +1013,8 @@ action_quick_reference_cb (GtkAction *action,
 			file = g_file_new_for_path (filename);
 			uri = g_file_get_uri (file);
 
-			g_app_info_launch_default_for_uri (uri, NULL, &error);
+			app_launched = g_app_info_launch_default_for_uri (
+				uri, NULL, &error);
 
 			if (error != NULL) {
 				/* FIXME Show an error dialog. */
