@@ -31,7 +31,7 @@
 #include <libevolution-utils/e-alert-dialog.h>
 #include <libevolution-utils/e-alert-sink.h>
 #include <libemail-utils/e-signature-utils.h>
-#include <misc/e-web-view.h>
+#include <misc/e-web-view-gtkhtml.h>
 
 #define E_SIGNATURE_EDITOR_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -40,7 +40,8 @@
 enum {
 	PROP_0,
 	PROP_FOCUS_TRACKER,
-	PROP_SIGNATURE
+	PROP_SIGNATURE,
+	PROP_EDITING_OLD
 };
 
 struct _ESignatureEditorPrivate {
@@ -49,6 +50,7 @@ struct _ESignatureEditorPrivate {
 	ESignature *signature;
 	GtkWidget *entry;
 	gchar *original_name;
+	gboolean editing_old;
 };
 
 static const gchar *ui =
@@ -254,6 +256,12 @@ signature_editor_set_property (GObject *object,
 				E_SIGNATURE_EDITOR (object),
 				g_value_get_object (value));
 			return;
+
+		case PROP_EDITING_OLD:
+			e_signature_editor_set_editing_old (
+				E_SIGNATURE_EDITOR (object),
+				g_value_get_boolean (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -277,6 +285,12 @@ signature_editor_get_property (GObject *object,
 				value, e_signature_editor_get_signature (
 				E_SIGNATURE_EDITOR (object)));
 			return;
+
+		case PROP_EDITING_OLD:
+			g_value_set_boolean (
+				value, e_signature_editor_get_editing_old (
+				E_SIGNATURE_EDITOR (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -389,6 +403,16 @@ e_signature_editor_class_init (ESignatureEditorClass *class)
 			NULL,
 			E_TYPE_SIGNATURE,
 			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_EDITING_OLD,
+		g_param_spec_boolean (
+			"editing-old",
+			NULL,
+			NULL,
+			FALSE,
+			G_PARAM_READWRITE));
 }
 
 static void
@@ -485,7 +509,7 @@ e_signature_editor_new (void)
 {
 	return g_object_new (
 		E_TYPE_SIGNATURE_EDITOR,
-		"html", e_web_view_new (), NULL);
+		"html", e_web_view_gtkhtml_new (), NULL);
 }
 
 EFocusTracker *
@@ -585,3 +609,25 @@ exit:
 
 	g_object_notify (G_OBJECT (editor), "signature");
 }
+
+void
+e_signature_editor_set_editing_old (ESignatureEditor *editor,
+                                    gboolean editing_old)
+{
+	g_return_if_fail (E_IS_SIGNATURE_EDITOR (editor));
+
+	if (editor->priv->editing_old == editing_old)
+		return;
+
+	editor->priv->editing_old = editing_old;
+
+	g_object_notify (G_OBJECT (editor), "editing-old");
+}
+
+gboolean
+e_signature_editor_get_editing_old (ESignatureEditor *editor)
+{
+	g_return_val_if_fail (E_IS_SIGNATURE_EDITOR (editor), FALSE);
+
+	return editor->priv->editing_old;
+}
