@@ -38,6 +38,7 @@
 #include <libevolution-utils/e-alert-sink.h>
 #include <e-util/e-plugin-ui.h>
 #include <e-util/e-file-request.h>
+#include <e-util/e-stock-request.h>
 
 #define LIBSOUP_USE_UNSTABLE_REQUEST_API
 #include <libsoup/soup.h>
@@ -968,7 +969,27 @@ web_view_scroll_event (GtkWidget *widget,
                        GdkEventScroll *event)
 {
 	if (event->state & GDK_CONTROL_MASK) {
-		switch (event->direction) {
+		GdkScrollDirection direction = event->direction;
+
+		#if GTK_CHECK_VERSION(3,3,18)
+		if (direction == GDK_SCROLL_SMOOTH) {
+			static gdouble total_delta_y = 0.0;
+
+			total_delta_y += event->delta_y;
+
+			if (total_delta_y >= 1.0) {
+				total_delta_y = 0.0;
+				direction = GDK_SCROLL_DOWN;
+			} else if (total_delta_y <= -1.0) {
+				total_delta_y = 0.0;
+				direction = GDK_SCROLL_UP;
+			} else {
+				return FALSE;
+			}
+		}
+		#endif
+
+		switch (direction) {
 			case GDK_SCROLL_UP:
 				e_web_view_zoom_in (E_WEB_VIEW (widget));
 				return TRUE;
@@ -1132,7 +1153,7 @@ web_view_load_string (EWebView *web_view,
 
 	webkit_web_view_load_string (
 		WEBKIT_WEB_VIEW (web_view),
-		string, "text/html", "UTF-8", "file://");
+		string, "text/html", "UTF-8", "evo-file:///");
 }
 
 static void
@@ -1162,7 +1183,7 @@ web_view_frame_load_string (EWebView *web_view,
 
 		if (frame)
 			webkit_web_frame_load_string (
-				frame, string, "text/html", "UTF-8", "file://");
+				frame, string, "text/html", "UTF-8", "evo-file:///");
 	}
 }
 
@@ -1281,35 +1302,28 @@ static void
 web_view_submit_alert (EAlertSink *alert_sink,
                        EAlert *alert)
 {
-	GtkIconInfo *icon_info;
 	EWebView *web_view;
 	GtkWidget *dialog;
 	GString *buffer;
 	const gchar *icon_name = NULL;
-	const gchar *filename;
 	gpointer parent;
-	gchar *icon_uri;
-	gint size = 0;
-	GError *error = NULL;
 
 	web_view = E_WEB_VIEW (alert_sink);
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (web_view));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
 
-	/* We use equivalent named icons instead of stock IDs,
-	 * since it's easier to get the filename of the icon. */
 	switch (e_alert_get_message_type (alert)) {
 		case GTK_MESSAGE_INFO:
-			icon_name = "dialog-information";
+			icon_name = GTK_STOCK_DIALOG_INFO;
 			break;
 
 		case GTK_MESSAGE_WARNING:
-			icon_name = "dialog-warning";
+			icon_name = GTK_STOCK_DIALOG_WARNING;
 			break;
 
 		case GTK_MESSAGE_ERROR:
-			icon_name = "dialog-error";
+			icon_name = GTK_STOCK_DIALOG_ERROR;
 			break;
 
 		default:
@@ -1319,21 +1333,6 @@ web_view_submit_alert (EAlertSink *alert_sink,
 			return;
 	}
 
-	gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &size, NULL);
-
-	icon_info = gtk_icon_theme_lookup_icon (
-		gtk_icon_theme_get_default (),
-		icon_name, size, GTK_ICON_LOOKUP_NO_SVG);
-	g_return_if_fail (icon_info != NULL);
-
-	filename = gtk_icon_info_get_filename (icon_info);
-	icon_uri = g_filename_to_uri (filename, NULL, &error);
-
-	if (error != NULL) {
-		g_warning ("%s", error->message);
-		g_clear_error (&error);
-	}
-
 	buffer = g_string_sized_new (512);
 
 	g_string_append (
@@ -1358,14 +1357,15 @@ web_view_submit_alert (EAlertSink *alert_sink,
 		buffer,
 		"<tr>"
 		"<td valign='top'>"
-		"<img src='%s'/>"
+		"<img src='gtk-stock://%s/?size=%d'/>"
 		"</td>"
 		"<td align='left' width='100%%'>"
 		"<h3>%s</h3>"
 		"%s"
 		"</td>"
 		"</tr>",
-		icon_uri,
+		icon_name,
+		GTK_ICON_SIZE_DIALOG,
 		e_alert_get_primary_text (alert),
 		e_alert_get_secondary_text (alert));
 
@@ -1381,9 +1381,6 @@ web_view_submit_alert (EAlertSink *alert_sink,
 	e_web_view_load_string (web_view, buffer->str);
 
 	g_string_free (buffer, TRUE);
-
-	gtk_icon_info_free (icon_info);
-	g_free (icon_uri);
 }
 
 static void
@@ -1725,6 +1722,7 @@ e_web_view_init (EWebView *web_view)
 	g_object_unref (web_settings);
 
 	e_web_view_install_request_handler (web_view, E_TYPE_FILE_REQUEST);
+	e_web_view_install_request_handler (web_view, E_TYPE_STOCK_REQUEST);
 
 	settings = g_settings_new ("org.gnome.desktop.interface");
 	g_signal_connect_swapped (
@@ -2865,7 +2863,7 @@ e_web_view_get_default_settings (void)
 }
 
 void
-e_web_view_update_fonts(EWebView *web_view)
+e_web_view_update_fonts (EWebView *web_view)
 {
 	GString *stylesheet;
 	gchar *base64;
@@ -2964,7 +2962,7 @@ e_web_view_update_fonts(EWebView *web_view)
 	gtk_style_context_get_style (context,
 		"link-color", &link,
 		"visited-link-color", &visited,
-                NULL);
+		NULL);
 
 	if (!link) {
 		link = g_new0 (GdkColor, 1);
@@ -2992,7 +2990,6 @@ e_web_view_update_fonts(EWebView *web_view)
 	if (visited)
 		gdk_color_free (visited);
 
-
 	base64 = g_base64_encode ((guchar *) stylesheet->str, stylesheet->len);
 	g_string_free (stylesheet, TRUE);
 
@@ -3018,7 +3015,7 @@ e_web_view_update_fonts(EWebView *web_view)
 
 void
 e_web_view_install_request_handler (EWebView *web_view,
-				    GType handler_type)
+                                    GType handler_type)
 {
 	SoupSession *session;
 	SoupSessionFeature *feature;
